@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------
 //
-//  Copyright (C) 2010 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2010-2014 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -49,18 +49,18 @@ int Pbutt1::handle_relse (void)
 
 
 
-Rlinctl::Rlinctl (X_window   *parent,
-                  X_callback *cbobj,
-                  RotaryImg  *image,
-                  int        xp,
-                  int        yp,
-		  int        cm,
-		  int        dd,
-                  double     vmin,
-	          double     vmax,
-	          double     vini,
-                  int        cbind) :
-RotaryCtl (parent, cbobj, image, xp, yp, cbind),
+Rlinctl::Rlinctl (X_window    *parent,
+                  X_callback  *cbobj,
+                  int          cbind,
+                  RotaryGeom  *rgeom,
+                  int          xp,
+                  int          yp,
+		  int          cm,
+		  int          dd,
+                  double       vmin,
+	          double       vmax,
+	          double       vini) :
+RotaryCtl (parent, cbobj, cbind, rgeom, xp, yp),
 _cm (cm),
 _dd (dd),
 _vmin (vmin),
@@ -115,18 +115,18 @@ int Rlinctl::set_count (int u)
 
 
 
-Rlogctl::Rlogctl (X_window   *parent,
-                  X_callback *cbobj,
-                  RotaryImg  *image,
-                  int        xp,
-                  int        yp,
-		  int        cm,
-		  int        dd,
-                  double     vmin,
-	          double     vmax,
-	          double     vini,
-                  int        cbind) :
-RotaryCtl (parent, cbobj, image, xp, yp, cbind),
+Rlogctl::Rlogctl (X_window    *parent,
+                  X_callback  *cbobj,
+                  int          cbind,
+                  RotaryGeom  *rgeom,
+                  int          xp,
+                  int          yp,
+		  int          cm,
+		  int          dd,
+                  double       vmin,
+	          double       vmax,
+	          double       vini) :
+RotaryCtl (parent, cbobj, cbind, rgeom, xp, yp),
 _cm (cm),
 _dd (dd),
 _form (0)
@@ -178,6 +178,3 @@ int Rlogctl::set_count (int u)
     }
     return 0;
 }
-
-
-
