@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------
 //
-//  Copyright (C) 2010 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2010-2014 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -73,17 +73,17 @@ class Rlinctl : public RotaryCtl
 {
 public:
 
-    Rlinctl (X_window   *parent,
-             X_callback *cbobj,
-             RotaryImg  *image,
-             int        xp,
-             int        yp,
-	     int        cm,
-	     int        dd,
-             double     vmin,
-	     double     vmax,
-	     double     vini,
-             int        cbind = 0);
+    Rlinctl (X_window    *parent,
+             X_callback  *cbobj,
+             int          cbind,
+             RotaryGeom  *rgeom,
+             int          xp,
+             int          yp,
+	     int          cm,
+	     int          dd,
+             double       vmin,
+	     double       vmax,
+	     double       vini);
 
     virtual void set_value (double v);
     virtual void get_string (char *p, int n);
@@ -109,15 +109,15 @@ public:
 
     Rlogctl (X_window   *parent,
              X_callback *cbobj,
-             RotaryImg  *image,
- 	     int        xp,
-             int        yp,
-	     int        cm,
-	     int        dd,
-             double     vmin,
-	     double     vmax,
-	     double     vini,
-             int        cbind = 0);
+             int          cbind,
+             RotaryGeom  *rgeom,
+             int          xp,
+             int          yp,
+	     int          cm,
+	     int          dd,
+             double       vmin,
+	     double       vmax,
+	     double       vini);
 
     virtual void set_value (double v);
     virtual void get_string (char *p, int n);
@@ -137,5 +137,4 @@ private:
 };
 
 
-
 #endif
