@@ -73,6 +73,7 @@ void Jclient::init_jack (const char *jname, const char *jserv)
 	
     _retuner = new Retuner (_fsamp);
     _notemask = 0xFFF;
+    _midichan = -1;
     clr_midimask ();
 
     _active = true;
@@ -127,19 +128,16 @@ void Jclient::midi_process (int nframes)
 	t = E.buffer [0];
         n = E.buffer [1];
 	v = E.buffer [2];
-	switch (t & 0xF0)
+	if ((_midichan < 0) || ((t & 0x0F) == _midichan))
 	{
-	case 0x80:
-	case 0x90:
-	    if (v && (t & 0x10))
+  	    switch (t & 0xF0)
 	    {
-		_notes [n % 12] += 1;
-	    }
-	    else
-	    {
-		_notes [n % 12] -= 1;
-	    }
-	    break;
+	    case 0x80:
+	    case 0x90:
+	        if (v && (t & 0x10))_notes [n % 12] += 1;
+  	        else _notes [n % 12] -= 1;
+	        break;
+  	    }
 	}
 	i++;
     }
