@@ -40,6 +40,7 @@ public:
     unsigned int fsamp (void) const { return _fsamp; } 
     Retuner *retuner (void) { return _retuner; }
     void set_notemask (int m) { _notemask = m; } 
+    void set_midichan (int c) { _midichan = c; } 
     void clr_midimask (void);
     int  get_noteset (void) { return _retuner->get_noteset (); }
     int  get_midiset (void) { return _midimask; }
@@ -66,6 +67,7 @@ private:
     int             _notes [12];
     int             _notemask;
     int             _midimask;
+    int             _midichan;
 
     static void jack_static_shutdown (void *arg);
     static int  jack_static_process (jack_nframes_t nframes, void *arg);
