@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------
 //
-//  Copyright (C) 2010 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2010-2014 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -52,7 +52,20 @@ Mainwin::Mainwin (X_rootwin *parent, X_resman *xres, int xp, int yp, Jclient *jc
     x_apply (&H); 
 
     x = 20;
+    _bmidi = new Pbutt0 (this, this, &b_midi_img, x, 12, B_MIDI);
+    _bmidi->x_map ();
+
+    bstyle1.size.x = 50;
+    bstyle1.size.y = 20;
+    _bchan = new X_tbutton (this, this, &bstyle1, x - 5, 40, "Omni", 0, B_CHAN);
+    _bchan->x_map ();
+    _midich = 0;
+    _jclient->set_midichan (-1);
+
+    x = 100;
     y = 23;
+    _tmeter = new Tmeter (this, x - 20, 53);
+    _tmeter->x_map ();
     for (i = j = 0; i < 12; i++, j++)
     {
         _bnote [i] = new Pbutt1 (this, this, &b_note_img, x, y, i);
@@ -70,20 +83,15 @@ Mainwin::Mainwin (X_rootwin *parent, X_resman *xres, int xp, int yp, Jclient *jc
 	    else       y -= 18;
 	} 
     }
-    x += 22;
-    _bmidi = new Pbutt0 (this, this, &b_midi_img, x, 6, B_MIDI);
-    _bmidi->x_map ();
-    _tmeter = new Tmeter (this, 15, 53);
-    _tmeter->x_map ();
 
 
     RotaryCtl::init (disp ());
-    x = 210;
-    _rotary [R_TUNE] = new Rlinctl (this, this, &r_tune_img, x, 0, 400,  5, 400.0, 480.0, 440.0, R_TUNE);
-    _rotary [R_BIAS] = new Rlinctl (this, this, &r_bias_img, x, 0, 270,  5,   0.0,   1.0,   0.5, R_BIAS);
-    _rotary [R_FILT] = new Rlogctl (this, this, &r_filt_img, x, 0, 200,  5,   0.50,  0.02,  0.1, R_FILT);
-    _rotary [R_CORR] = new Rlinctl (this, this, &r_corr_img, x, 0, 270,  5,   0.0,   1.0,   1.0, R_CORR);
-    _rotary [R_OFFS] = new Rlinctl (this, this, &r_offs_img, x, 0, 400, 10,  -2.0,   2.0,   0.0, R_OFFS);
+    x = 270;
+    _rotary [R_TUNE] = new Rlinctl (this, this, R_TUNE, &r_tune_geom, x, 0, 400,  5, 400.0, 480.0, 440.0);
+    _rotary [R_BIAS] = new Rlinctl (this, this, R_BIAS, &r_bias_geom, x, 0, 270,  5,   0.0,   1.0,   0.5);
+    _rotary [R_FILT] = new Rlogctl (this, this, R_FILT, &r_filt_geom, x, 0, 200,  5,   0.50,  0.02,  0.1);
+    _rotary [R_CORR] = new Rlinctl (this, this, R_CORR, &r_corr_geom, x, 0, 270,  5,   0.0,   1.0,   1.0);
+    _rotary [R_OFFS] = new Rlinctl (this, this, R_OFFS, &r_offs_geom, x, 0, 400, 10,  -2.0,   2.0,   0.0);
     for (i = 0; i < NROTARY; i++) _rotary [i]->x_map ();
 
     _textln = new X_textip (this, 0, &tstyle1, 0, 0, 50, 15, 15);
@@ -199,6 +207,28 @@ void Mainwin::handle_callb (int type, X_window *W, XEvent *E)
 
     switch (type)
     {
+    case X_callback::BUTTON | X_button::PRESS:
+    {
+        X_button     *Z = (X_button *) W;
+	XButtonEvent *X = (XButtonEvent *) E;
+	switch (Z->cbid ())
+	{
+	case B_CHAN:
+	    switch (X->button)
+	    {
+	    case 1:
+	    case 4:
+		setchan (1);
+	        break;
+	    case 3:
+	    case 5:
+		setchan (-1);
+	        break;
+	    }
+            break;
+	}
+	break;
+    }
     case PushButton::PRESS:
 	B = (PushButton *) W;
 	k = B->cbind ();
@@ -256,6 +286,23 @@ void Mainwin::handle_callb (int type, X_window *W, XEvent *E)
 }
 
 
+void Mainwin::setchan (int d)
+{
+    char s [16];
+
+    _midich += d;
+    if (_midich <  0) _midich =  0;
+    if (_midich > 16) _midich = 16;
+    if (_midich)
+    {
+        sprintf (s, "Ch %d\n", _midich);
+	_bchan->set_text (s, 0);
+    }
+    else _bchan->set_text ("Omni", 0);
+    _jclient->set_midichan (_midich - 1);
+}   
+
+
 void Mainwin::showval (int k)
 {
     char s [16];
@@ -281,9 +328,9 @@ void Mainwin::redraw (void)
 {
     int x;
 
-    x = 0;
-    XPutImage (dpy (), win (), dgc (), notesect_img, 0, 0, x, 0, 210, 75);
-    x += 210;
+    x = 80;
+    XPutImage (dpy (), win (), dgc (), notesect_img, 0, 0, x, 0, 190, 75);
+    x += 190;
     XPutImage (dpy (), win (), dgc (), ctrlsect_img, 0, 0, x, 0, 315, 75);
     x = XSIZE - 35;
     XPutImage (dpy (), win (), dgc (), redzita_img, 0, 0, x, 0, 35, 75);
