@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------
 //
-//  Copyright (C) 2010 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2010-2014 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -46,7 +46,7 @@ public:
 
 private:
 
-    enum { B_MIDI = 12 };
+    enum { B_MIDI = 12, B_CHAN = 13 };
     enum { R_TUNE, R_FILT, R_BIAS, R_CORR, R_OFFS, NROTARY };
  
     virtual void thr_main (void) {}
@@ -59,6 +59,7 @@ private:
     void expose (XExposeEvent *E);
     void clmesg (XClientMessageEvent *E);
     void redraw (void);
+    void setchan (int d);
 
     Atom            _atom;
     bool            _stop;
@@ -71,6 +72,8 @@ private:
     RotaryCtl      *_rotary [NROTARY];
     Tmeter         *_tmeter;
     X_textip       *_textln;
+    X_tbutton      *_bchan;
+    int             _midich;
     int             _ttimer;
 };
 
