@@ -24,7 +24,7 @@
 
 
 #include <fftw3.h>
-#include <zita-resampler.h>
+#include <zita-resampler/resampler.h>
 
 
 class Retuner
