@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------
 //
-//  Copyright (C) 2010 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2010-2012 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 cairo_t         *RotaryCtl::_cairotype = 0;
 cairo_surface_t *RotaryCtl::_cairosurf = 0;
 
+
 int RotaryCtl::_wb_up = 4;
 int RotaryCtl::_wb_dn = 5;
 int RotaryCtl::_keymod = 0;
@@ -39,18 +40,18 @@ int RotaryCtl::_ry = 0;
 
 RotaryCtl::RotaryCtl (X_window     *parent,
                       X_callback   *cbobj,
-                      RotaryImg    *image,
-		      int  xp,
-                      int  yp,
-                      int  cbind) :
+		      int           cbind,
+                      RotaryGeom   *rgeom,
+		      int           xp,
+                      int           yp) :
 
     X_window (parent,
-              image->_x0 + xp, image->_y0 + yp,
-              image->_dx, image->_dy,
-              image->_backg->pixel),
+              rgeom->_x0 + xp, rgeom->_y0 + yp,
+              rgeom->_dx, rgeom->_dy,
+              rgeom->_backg->pixel),
     _cbobj (cbobj),
     _cbind (cbind),
-    _image (image),
+    _rgeom (rgeom),
     _state (0),
     _count (0),
     _value (0),
@@ -111,8 +112,8 @@ void RotaryCtl::bpress (XButtonEvent *E)
     int    r = 0;
     double d;
 
-    d = hypot (E->x - _image->_xref, E->y - _image->_yref);
-    if (d > _image->_rad + 3) return;
+    d = hypot (E->x - _rgeom->_xref, E->y - _rgeom->_yref);
+    if (d > _rgeom->_rad + 3) return;
     _keymod  = E->state;
     if (E->button < 4)
     {
@@ -183,23 +184,23 @@ void RotaryCtl::render (void)
     XImage  *I;
     double  a, c, r, x, y;
 
-    I = _image->_image [_state];
+    I = _rgeom->_image [_state];
     XPutImage (dpy (), win (), dgc (), I,
-               _image->_x0, _image->_y0, 0, 0, _image->_dx, _image->_dy);
+               _rgeom->_x0, _rgeom->_y0, 0, 0, _rgeom->_dx, _rgeom->_dy);
     cairo_xlib_surface_set_drawable (_cairosurf, win(),
-                                     _image->_dx, _image->_dy);
-    c = _image->_lncol [_state] ? 1.0 : 0.0;
+                                     _rgeom->_dx, _rgeom->_dy);
+    c = _rgeom->_lncol [_state] ? 1.0 : 0.0;
     a = _angle * M_PI / 180;
-    r = _image->_rad;
-    x = _image->_xref;
-    y = _image->_yref;
+    r = _rgeom->_rad;
+    x = _rgeom->_xref;
+    y = _rgeom->_yref;
     cairo_new_path (_cairotype);
     cairo_move_to (_cairotype, x, y);
     x += r * sin (a);
     y -= r * cos (a);
     cairo_line_to (_cairotype, x, y);
     cairo_set_source_rgb (_cairotype, c, c, c);
-    cairo_set_line_width (_cairotype, 1.8);
+    cairo_set_line_width (_cairotype, 2.2);
     cairo_stroke (_cairotype);
 }
 
