@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------
 //
-//  Copyright (C) 2010-2011 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2010-2014 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@ XftColor      *XftColors [NXFTCOLORS];
 XftFont       *XftFonts [NXFTFONTS];
 
 X_textln_style tstyle1;
+X_button_style bstyle1;
 
 XImage    *notesect_img;
 XImage    *ctrlsect_img;
@@ -36,11 +37,11 @@ XImage    *redzita_img;
 ButtonImg  b_note_img;
 ButtonImg  b_midi_img;
 
-RotaryImg  r_tune_img;
-RotaryImg  r_filt_img;
-RotaryImg  r_bias_img;
-RotaryImg  r_corr_img;
-RotaryImg  r_offs_img;
+RotaryGeom  r_tune_geom;
+RotaryGeom  r_filt_geom;
+RotaryGeom  r_bias_geom;
+RotaryGeom  r_corr_geom;
+RotaryGeom  r_offs_geom;
 
 
 void styles_init (X_display *disp, X_resman *xrm)
@@ -51,11 +52,17 @@ void styles_init (X_display *disp, X_resman *xrm)
     XftColors [C_TEXT_FG] = disp->alloc_xftcolor (0.1f, 0.1f, 0.1f, 1.0f);
 
     XftFonts [F_TEXT] = disp->alloc_xftfont (xrm->get (".font.text", "luxi:bold::pixelsize=11"));
+    XftFonts [F_BUTT] = disp->alloc_xftfont (xrm->get (".font.butt", "luxi:bold::pixelsize=11"));
 
     tstyle1.font = XftFonts [F_TEXT];
     tstyle1.color.normal.bgnd = XftColors [C_TEXT_BG]->pixel;
     tstyle1.color.normal.text = XftColors [C_TEXT_FG];
 
+    bstyle1.font =  XftFonts [F_BUTT];
+    bstyle1.color.bg[0] = XftColors [C_MAIN_BG]->pixel;
+    bstyle1.color.fg[0] = XftColors [C_MAIN_FG];
+    bstyle1.type = X_button_style::PLAIN | X_button_style::ALEFT;
+
     notesect_img = png2img (SHARED"/notesect.png", disp, XftColors [C_MAIN_BG]);
     ctrlsect_img = png2img (SHARED"/ctrlsect.png", disp, XftColors [C_MAIN_BG]);
     redzita_img  = png2img (SHARED"/redzita.png",  disp, XftColors [C_MAIN_BG]); 
@@ -74,8 +81,8 @@ void styles_init (X_display *disp, X_resman *xrm)
     b_midi_img._ximage = png2img (SHARED"/midi.png", disp, XftColors [C_MAIN_BG]);
     b_midi_img._x0 = 0;
     b_midi_img._y0 = 0;
-    b_midi_img._dx = 35;
-    b_midi_img._dy = 19;
+    b_midi_img._dx = 40;
+    b_midi_img._dy = 24;
 
     b_note_img._backg = XftColors [C_MAIN_BG];
     b_note_img._ximage = png2img (SHARED"/note.png", disp, XftColors [C_MAIN_BG]);
@@ -84,60 +91,60 @@ void styles_init (X_display *disp, X_resman *xrm)
     b_note_img._dx = 16;
     b_note_img._dy = 16;
 
-    r_tune_img._backg = XftColors [C_MAIN_BG];
-    r_tune_img._image [0] = ctrlsect_img;
-    r_tune_img._lncol [0] = 1;
-    r_tune_img._x0 = 26;
-    r_tune_img._y0 = 17;
-    r_tune_img._dx = 23;
-    r_tune_img._dy = 23;
-    r_tune_img._xref = 11.5;
-    r_tune_img._yref = 11.5;
-    r_tune_img._rad = 11;
+    r_tune_geom._backg = XftColors [C_MAIN_BG];
+    r_tune_geom._image [0] = ctrlsect_img;
+    r_tune_geom._lncol [0] = 1;
+    r_tune_geom._x0 = 26;
+    r_tune_geom._y0 = 17;
+    r_tune_geom._dx = 23;
+    r_tune_geom._dy = 23;
+    r_tune_geom._xref = 11.5;
+    r_tune_geom._yref = 11.5;
+    r_tune_geom._rad = 11;
 
-    r_bias_img._backg = XftColors [C_MAIN_BG];
-    r_bias_img._image [0] = ctrlsect_img;
-    r_bias_img._lncol [0] = 0;
-    r_bias_img._x0 = 86;
-    r_bias_img._y0 = 17;
-    r_bias_img._dx = 23;
-    r_bias_img._dy = 23;
-    r_bias_img._xref = 11.5;
-    r_bias_img._yref = 11.5;
-    r_bias_img._rad = 11;
+    r_bias_geom._backg = XftColors [C_MAIN_BG];
+    r_bias_geom._image [0] = ctrlsect_img;
+    r_bias_geom._lncol [0] = 0;
+    r_bias_geom._x0 = 86;
+    r_bias_geom._y0 = 17;
+    r_bias_geom._dx = 23;
+    r_bias_geom._dy = 23;
+    r_bias_geom._xref = 11.5;
+    r_bias_geom._yref = 11.5;
+    r_bias_geom._rad = 11;
 
-    r_filt_img._backg = XftColors [C_MAIN_BG];
-    r_filt_img._image [0] = ctrlsect_img;
-    r_filt_img._lncol [0] = 0;
-    r_filt_img._x0 = 146;
-    r_filt_img._y0 = 17;
-    r_filt_img._dx = 23;
-    r_filt_img._dy = 23;
-    r_filt_img._xref = 11.5;
-    r_filt_img._yref = 11.5;
-    r_filt_img._rad = 11;
+    r_filt_geom._backg = XftColors [C_MAIN_BG];
+    r_filt_geom._image [0] = ctrlsect_img;
+    r_filt_geom._lncol [0] = 0;
+    r_filt_geom._x0 = 146;
+    r_filt_geom._y0 = 17;
+    r_filt_geom._dx = 23;
+    r_filt_geom._dy = 23;
+    r_filt_geom._xref = 11.5;
+    r_filt_geom._yref = 11.5;
+    r_filt_geom._rad = 11;
 
-    r_corr_img._backg = XftColors [C_MAIN_BG];
-    r_corr_img._image [0] = ctrlsect_img;
-    r_corr_img._lncol [0] = 0;
-    r_corr_img._x0 = 206;
-    r_corr_img._y0 = 17;
-    r_corr_img._dx = 23;
-    r_corr_img._dy = 23;
-    r_corr_img._xref = 11.5;
-    r_corr_img._yref = 11.5;
-    r_corr_img._rad = 11;
+    r_corr_geom._backg = XftColors [C_MAIN_BG];
+    r_corr_geom._image [0] = ctrlsect_img;
+    r_corr_geom._lncol [0] = 0;
+    r_corr_geom._x0 = 206;
+    r_corr_geom._y0 = 17;
+    r_corr_geom._dx = 23;
+    r_corr_geom._dy = 23;
+    r_corr_geom._xref = 11.5;
+    r_corr_geom._yref = 11.5;
+    r_corr_geom._rad = 11;
 
-    r_offs_img._backg = XftColors [C_MAIN_BG];
-    r_offs_img._image [0] = ctrlsect_img;
-    r_offs_img._lncol [0] = 0;
-    r_offs_img._x0 = 266;
-    r_offs_img._y0 = 17;
-    r_offs_img._dx = 23;
-    r_offs_img._dy = 23;
-    r_offs_img._xref = 11.5;
-    r_offs_img._yref = 11.5;
-    r_offs_img._rad = 11;
+    r_offs_geom._backg = XftColors [C_MAIN_BG];
+    r_offs_geom._image [0] = ctrlsect_img;
+    r_offs_geom._lncol [0] = 0;
+    r_offs_geom._x0 = 266;
+    r_offs_geom._y0 = 17;
+    r_offs_geom._dx = 23;
+    r_offs_geom._dy = 23;
+    r_offs_geom._xref = 11.5;
+    r_offs_geom._yref = 11.5;
+    r_offs_geom._rad = 11;
 }
 
 
