@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------
 //
-//  Copyright (C) 2010-2011 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2010-2014 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -37,6 +37,7 @@ enum
 enum
 {
     F_TEXT,
+    F_BUTT,
     NXFTFONTS
 };
 
@@ -48,17 +49,18 @@ extern XftColor  *XftColors [NXFTCOLORS];
 extern XftFont   *XftFonts [NXFTFONTS];
 
 extern X_textln_style tstyle1;
+extern X_button_style bstyle1;
 
-extern XImage    *notesect_img;
-extern XImage    *ctrlsect_img;
-extern XImage    *redzita_img;
-extern ButtonImg  b_midi_img;
-extern ButtonImg  b_note_img;
-extern RotaryImg  r_tune_img;
-extern RotaryImg  r_filt_img;
-extern RotaryImg  r_bias_img;
-extern RotaryImg  r_corr_img;
-extern RotaryImg  r_offs_img;
+extern XImage     *notesect_img;
+extern XImage     *ctrlsect_img;
+extern XImage     *redzita_img;
+extern ButtonImg   b_midi_img;
+extern ButtonImg   b_note_img;
+extern RotaryGeom  r_tune_geom;
+extern RotaryGeom  r_filt_geom;
+extern RotaryGeom  r_bias_geom;
+extern RotaryGeom  r_corr_geom;
+extern RotaryGeom  r_offs_geom;
 
 
 #endif
